%define pypi_name pbr

%bcond_with docs

Name:           python-%{pypi_name}
Version:        5.10.0
Release:        %mkrel 1
Summary:        Python Build Reasonableness
Group:          Development/Python
License:        MIT
URL:            https://pypi.org/project/pbr
Source0:        %{pypi_source}
BuildArch:      noarch
BuildRequires: pyproject-rpm-macros
%if %{with docs}
BuildRequires:  python3dist(sphinx)
BuildRequires:  python3dist(sphinx-rtd-theme)
%endif

%description
PBR is a library that injects some useful and sensible default
behaviors into your setuptools run. It started off life as the
chunks of code that were copied between all of the OpenStack
projects. Around the time that OpenStack hit 18 different projects
each with at least 3 active branches, it seems like a good time to
make that code into a proper re-usable library.

%package -n python3-%{pypi_name}
Summary:        Python Build Reasonableness
Group:          Development/Python
BuildRequires:  pkgconfig(python3)
BuildRequires:  python3dist(setuptools)
%{?python_provide:%python_provide python3-%{pypi_name}}

%description -n python3-%{pypi_name}
Manage dynamic plugins for Python applications.

%prep
%setup -q -n %{pypi_name}-%{version}


%build
%pyproject_wheel

%if %{with docs}
PYTHONPATH=$(pwd) sphinx-build doc/source html
# remove the sphinx-build leftovers
rm -rf html/.{doctrees,buildinfo}
%endif

%install
%pyproject_install
%pyproject_save_files pbr

%files -n python3-%{pypi_name} -f %{pyproject_files}
%license LICENSE
%doc README.rst
%if %{with docs}
%doc html
%endif

%{_bindir}/pbr


%changelog
* Wed Sep 07 2022 neoclust <neoclust> 5.10.0-1.mga9
+ Revision: 1885330
- New version  5.10.0

* Wed Mar 23 2022 umeabot <umeabot> 5.8.1-2.mga9
+ Revision: 1823115
- Mageia 9 Mass Rebuild

* Sat Feb 19 2022 joequant <joequant> 5.8.1-1.mga9
+ Revision: 1781405
- update to 5.8.1 / python 3.10

* Sun Feb 06 2022 wally <wally> 5.6.0-2.mga9
+ Revision: 1771878
- rebuild for python3.10

* Sun Aug 29 2021 wally <wally> 5.6.0-1.mga9
+ Revision: 1743466
- new version 5.6.0

* Sun Mar 14 2021 wally <wally> 5.5.1-2.mga9
+ Revision: 1702600
- rebuild for python 3.9

* Sat Nov 28 2020 guillomovitch <guillomovitch> 5.5.1-1.mga8
+ Revision: 1649912
- new version 5.5.1

* Fri Oct 23 2020 daviddavid <daviddavid> 5.5.0-1.mga8
+ Revision: 1638952
- new version: 5.5.0

* Wed Apr 29 2020 wally <wally> 5.4.5-1.mga8
+ Revision: 1573272
- new version 5.4.5

* Sun Feb 16 2020 umeabot <umeabot> 5.4.3-2.mga8
+ Revision: 1534274
- Mageia 8 Mass Rebuild

* Wed Oct 02 2019 daviddavid <daviddavid> 5.4.3-1.mga8
+ Revision: 1448752
- new version: 5.4.3

* Wed Sep 04 2019 wally <wally> 5.4.2-2.mga8
+ Revision: 1437156
- rebuild with new python-rpm-macros

* Tue Sep 03 2019 wally <wally> 5.4.2-1.mga8
+ Revision: 1436795
- new version 5.4.2
- disable python2 support
- rebuild for python3.8
- disable doc build for rebuild

* Sat Apr 20 2019 wally <wally> 5.1.3-1.mga7
+ Revision: 1393689
- new version 5.1.3

* Wed Jan 09 2019 kekepower <kekepower> 3.1.1-6.mga7
+ Revision: 1353288
- Use python*dist()
- Use python_provide
- Renamed python-pbr to python2-pbr

* Tue Jan 08 2019 tv <tv> 3.1.1-5.mga7
+ Revision: 1352074
- rebuild with python 3.7

* Sat Jan 05 2019 wally <wally> 3.1.1-4.mga7
+ Revision: 1349271
- rebuild for python3.7

* Thu Sep 20 2018 umeabot <umeabot> 3.1.1-3.mga7
+ Revision: 1289661
- Mageia 7 Mass Rebuild

* Thu Aug 03 2017 philippem <philippem> 3.1.1-2.mga7
+ Revision: 1134423
- update to 3.1.1
- rebuild for Python 3.6

* Wed Dec 16 2015 daviddavid <daviddavid> 1.8.1-1.mga6
+ Revision: 911043
- new version: 1.8.1
- add python3-pbr binary

* Wed Oct 07 2015 philippem <philippem> 1.8.0-1.mga6
+ Revision: 887160
- add BR python-sphinx_rtd_theme
- update to 1.8.0

* Fri Aug 28 2015 philippem <philippem> 1.6.0-1.mga6
+ Revision: 870620
- update to 1.6.0

* Wed Dec 03 2014 joequant <joequant> 0.8.0-6.mga5
+ Revision: 800419
- add python sphinx
- build for python3

* Wed Oct 15 2014 umeabot <umeabot> 0.8.0-5.mga5
+ Revision: 747614
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 0.8.0-4.mga5
+ Revision: 726920
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 0.8.0-3.mga5
+ Revision: 688207
- Mageia 5 Mass Rebuild
+ pterjan <pterjan>
- Rebuild for new Python

* Sun Mar 30 2014 kharec <kharec> 0.8.0-1.mga5
+ Revision: 610672
- update to 0.8.0 to fix keystone client installation

* Tue Oct 22 2013 umeabot <umeabot> 0.5.21-3.mga4
+ Revision: 543913
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 pterjan <pterjan> 0.5.21-2.mga4
+ Revision: 499110
- Rebuild to add different pythonegg provides for python 2 and 3

* Mon Oct 07 2013 neoclust <neoclust> 0.5.21-1.mga4
+ Revision: 492560
- New version 0.5.21

* Tue Jul 30 2013 neoclust <neoclust> 0.5.19-3.mga4
+ Revision: 460731
- imported package python-pbr

